@@ -664,7 +664,13 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
     wh['date'] = wh.index
     wh = pd.merge(wh, converted_history_balance, how='left', left_on='date', right_on ='ts')
 
-    wh.at[wh.index[0], 'realized_pnl'] = wh.at[wh.index[0], 'convertedWalletBalance']
+    wh = wh.rename(columns={"convertedWalletBalance": "wallet_balance"})
+
+    starting_index = 0
+    while np.isnan(wh.at[wh.index[starting_index], 'wallet_balance']) == True:
+        starting_index = starting_index + 1
+
+    wh.at[wh.index[starting_index], 'realized_pnl'] = wh.at[wh.index[starting_index], 'wallet_balance']
 
     wh['net_profit'] = wh.realized_pnl + wh.funding_fees_eth_usd + wh.funding_fees_xbt_usd + wh.trading_fees_eth_usd + wh.trading_fees_xbt_usd
     wh['valuation'] = wh.net_profit + wh.transfers_usd
@@ -675,7 +681,7 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
 
     x = td[['traded_eth', 'avg_eth_price', 'amount_traded_usd_eth', 'sens_trade_eth', 'open_eth_cc', 'open_eth_bnc',
             'traded_xbt', 'avg_btc_price', 'amount_traded_usd_btc', 'sens_trade_xbt', 'open_btc_cc', 'open_btc_bnc',
-            'valuation', 'transfers_usd',
+            'valuation', 'transfers_usd','wallet_balance',
             'trading_fees_eth_usd', 'funding_fees_eth_usd', 'slippage_eth_price_cc', 'slippage_eth_cash_cc','slippage_eth_price_bnc', 'slippage_eth_cash_bnc',
             'trading_fees_xbt_usd', 'funding_fees_xbt_usd', 'slippage_btc_price_cc', 'slippage_btc_cash_cc','slippage_btc_price_bnc', 'slippage_btc_cash_bnc' ]]
 
@@ -684,7 +690,7 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
                  'open_eth_cc', 'open_eth_exchange',
                  'quantity_traded_btc', 'avg_traded_price_btc', 'amount_traded_usd_btc', 'n_trades_btc',
                  'open_btc_cc', 'open_btc_exchange',
-                 'wallet_amount_usd', 'transfers_usd',
+                 'wallet_amount_usd', 'transfers_usd','wallet_binance_balance',
                  'trading_fees_usd_eth', 'funding_fees_usd_eth', 'slippage_eth_price_cc', 'slippage_eth_cash_cc','slippage_eth_price_bnc', 'slippage_eth_cash_bnc',
                  'trading_fees_usd_btc', 'funding_fees_usd_btc', 'slippage_btc_price_cc', 'slippage_btc_cash_cc','slippage_btc_price_bnc', 'slippage_btc_cash_bnc' ]
 
